import "./Avatar.css";
import { ComponentProps, ElementType, ForwardedRef, ReactNode } from "react";
export interface InnerAvatarProps {
    /**
     * The name of the person in the avatar.
     */
    name: string;
    /**
     * The url of a remote image or an image object.
     */
    src?: string | ReactNode;
    /**
     * The allowed number of retry to load a remote image.
     */
    retryCount?: number;
    /**
     * An avatar can vary in size.
     */
    size?: "2xs" | "xs" | "sm" | "md" | "lg" | "xl" | "2xl";
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * Default slot override.
     */
    slot?: string;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare type AvatarTextProps = Partial<AvatarProps> & {
    children: ReactNode;
};
export declare function AvatarText({ size, as, children, ...rest }: AvatarTextProps): JSX.Element;
export declare function InnerAvatar({ name, src, retryCount, size, as, forwardedRef, ...rest }: InnerAvatarProps): JSX.Element;
export declare const Avatar: import("../../shared").OrbitComponent<HTMLElement, InnerAvatarProps>;
export declare type AvatarProps = ComponentProps<typeof Avatar>;
