import { AvatarText } from "./Avatar";
import { Box } from "../../box";
import { Children } from "react";
import { Group } from "../../group";
import { Tooltip, TooltipTrigger } from "../../tooltip";
import { augmentElement, cssModule, forwardRef, mergeClasses, mergeProps, normalizeSize } from "../../shared";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

function RemainingAvatars({
  count,
  size,
  ...rest
}) {
  return /*#__PURE__*/_jsx(Box, { ...mergeProps(rest, {
      className: mergeClasses("o-ui-avatar-group-remainings", cssModule("o-ui-avatar", normalizeSize(size)))
    }),
    children: /*#__PURE__*/_jsx(AvatarText, {
      size: size,
      children: `+${count}`
    })
  });
}

const AvailableSlots = 4;
export function InnerAvatarGroup({
  size,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  const avatars = Children.toArray(children);
  const isExceeding = avatars.length > AvailableSlots;
  const shownAvatars = isExceeding ? avatars.slice(0, AvailableSlots - 1) : avatars;
  const remainingAvatars = isExceeding ? avatars.slice(AvailableSlots - 1) : null;
  const avatarsMarkup = shownAvatars.map(x => {
    return augmentElement(x, {
      size
    });
  });

  const remainingAvatarsMarkup = remainingAvatars && /*#__PURE__*/_jsx(RemainingAvatars, {
    count: remainingAvatars.length,
    size: size
  });

  return /*#__PURE__*/_jsxs(TooltipTrigger, {
    children: [/*#__PURE__*/_jsxs(Group, { ...mergeProps(rest, {
        gap: 1,
        className: "o-ui-avatar-group",
        as,
        ref: forwardedRef
      }),
      children: [avatarsMarkup, remainingAvatarsMarkup]
    }), /*#__PURE__*/_jsx(Tooltip, {
      children: avatars.map(x => {
        var _x$props;

        return x === null || x === void 0 ? void 0 : (_x$props = x.props) === null || _x$props === void 0 ? void 0 : _x$props.name;
      }).filter(x => x).join("\r\n")
    })]
  });
}
export const AvatarGroup = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerAvatarGroup, { ...props,
  forwardedRef: ref
}));
AvatarGroup.displayName = "AvatarGroup";