import { forwardRef, isNil, mergeProps, resolveChildren, slot, useCheckableProps } from "../../shared";
import { IconButton } from "./IconButton";
import { useToggleButton } from "./useToggleButton";
import { jsx as _jsx } from "react/jsx-runtime";
export function InnerToggleIconButton(props) {
  const [checkableProps, isCheckable] = useCheckableProps(props);
  const {
    variant = "solid",
    shape = "circular",
    checked,
    defaultChecked,
    value,
    onChange,
    active,
    "aria-label": ariaLabel,
    as,
    children,
    forwardedRef,
    ...rest
  } = mergeProps(props, checkableProps);

  if (isNil(ariaLabel)) {
    console.error("A toggle icon button component must have an \"aria-label\" attribute.");
  }

  const {
    isChecked,
    buttonProps
  } = useToggleButton({
    variant,
    shape,
    checked,
    defaultChecked,
    value,
    onChange,
    active,
    isCheckable,
    forwardedRef
  });
  const content = resolveChildren(children, {
    isChecked
  });
  return /*#__PURE__*/_jsx(IconButton, { ...mergeProps({
      as: as,
      "aria-label": ariaLabel
    }, rest, buttonProps),
    children: content
  });
}
export const ToggleIconButton = slot("button", forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerToggleIconButton, { ...props,
  forwardedRef: ref
})));
ToggleIconButton.displayName = "ToggleIconButton";