import { isNil, useControllableState, useEventCallback } from "../../shared";
// The shape is generic since ToggleButton and ToggleIconButton don't allow the same shapes. The output type of useToggleButton
// must forward the exact shape type as the one received in the parameters.
export function useToggleButton({
  variant,
  shape,
  checked,
  defaultChecked,
  value,
  onChange,
  onCheck,
  active,
  isCheckable,
  forwardedRef
}) {
  const [isChecked, setIsChecked] = useControllableState(checked, defaultChecked, false);
  const handleClick = useEventCallback(event => {
    setIsChecked(!isChecked);

    if (!isNil(onCheck)) {
      onCheck(event, value);
    }

    if (!isNil(onChange)) {
      onChange(event, !isChecked);
    }
  });
  return {
    isChecked,
    buttonProps: {
      variant,
      shape,
      onClick: handleClick,
      value,
      active: active || isChecked,
      [isCheckable ? "aria-checked" : "aria-pressed"]: isChecked,
      ref: forwardedRef
    }
  };
}