import "./Checkbox.css";
import { AriaLabelingProps, InteractionStatesProps } from "../../shared";
import { ChangeEvent, ComponentProps, ElementType, ForwardedRef, ReactNode } from "react";
export interface InnerCheckboxProps extends InteractionStatesProps, AriaLabelingProps {
    /**
     * @ignore
     */
    name?: string;
    /**
     * @ignore
     */
    tabIndex?: number;
    /**
    * A controlled checked state value.
    */
    checked?: boolean | null;
    /**
     * The initial value of `checked` when uncontrolled.
     */
    defaultChecked?: boolean;
    /**
     * A controlled indeterminate state value.
     */
    indeterminate?: boolean | null;
    /**
     * The initial value of `indeterminate`.
     */
    defaultIndeterminate?: boolean;
    /**
     * The value to associate with when in a group.
     */
    value?: string;
    /**
     * Whether or not the checkbox should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * Whether or not a user input is required before form submission.
     */
    required?: boolean;
    /**
     * Whether or not the checkbox should display as "valid" or "invalid".
     */
    validationState?: "valid" | "invalid";
    /**
     * A checkbox can vary in size.
     */
    size?: "sm" | "md";
    /**
     * Whether or not the checkbox is disabled.
     */
    disabled?: boolean;
    /**
     * Invert the order the checkmark box and the label.
     */
    reverse?: boolean;
    /**
     * Called when the checkbox checked state change.
     * @param {ChangeEvent} event - React's original synthetic event.
     * @param {boolean} isChecked - Whether or not the input is checked.
     * @returns {void}
     */
    onValueChange?: (event: ChangeEvent<HTMLInputElement>, isChecked: boolean) => void;
    /**
     * @ignore
     */
    onChange?: (event: ChangeEvent<HTMLInputElement>) => void;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * @ignore
     */
    children?: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerCheckbox(props: InnerCheckboxProps): JSX.Element;
export declare const Checkbox: import("../../shared").OrbitComponent<HTMLElement, InnerCheckboxProps>;
export declare type CheckboxProps = ComponentProps<typeof Checkbox>;
