import "./Checkbox.css";
import { forwardRef, isNil, mergeProps, omitProps, resolveChildren, useChainedEventCallback, useCheckableProps, useSlots } from "../../shared";
import { Box } from "../../box";
import { useMemo } from "react";
import { Text } from "../../text";
import { VisuallyHidden } from "../../visually-hidden";
import { embeddedIconSize } from "../../icons";
import { useCheckbox } from "./useCheckbox";
import { useFieldInputProps } from "../../field";
import { useToolbarProps } from "../../toolbar";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerCheckbox(props) {
  const [checkableProps] = useCheckableProps(props);
  const [fieldProps, isInField] = useFieldInputProps();
  const [toolbarProps] = useToolbarProps();
  const {
    id,
    checked,
    defaultChecked,
    indeterminate,
    defaultIndeterminate,
    value,
    autoFocus,
    required,
    validationState,
    onValueChange,
    onChange,
    onCheck,
    size,
    reverse,
    name,
    tabIndex,
    active,
    focus,
    hover,
    disabled,
    "aria-label": ariaLabel,
    // Usually provided by the field inputs.
    "aria-labelledby": ariaLabelledBy,
    as = "label",
    children,
    forwardedRef,
    ...rest
  } = mergeProps(omitProps(props, ["role"]), checkableProps, omitProps(toolbarProps, ["orientation"]), omitProps(fieldProps, ["fluid"]));

  if (isNil(children) && isNil(ariaLabel) && isNil(ariaLabelledBy)) {
    console.error("A checkbox must either have children, an \"aria-label\" attribute or an \"aria-labelledby\" attribute.");
  }

  const handleChange = useChainedEventCallback(onChange, (event, isChecked) => {
    if (!isNil(onValueChange)) {
      onValueChange(event, isChecked);
    }

    if (!isNil(onCheck)) {
      onCheck(event, value);
    }
  });
  const {
    wrapperProps,
    inputProps
  } = useCheckbox({
    cssModule: "o-ui-checkbox",
    isInField,
    id,
    checked,
    defaultChecked,
    indeterminate,
    defaultIndeterminate,
    autoFocus,
    required,
    validationState,
    onChange: handleChange,
    size,
    reverse,
    name,
    tabIndex,
    active,
    focus,
    hover,
    disabled,
    ariaLabel,
    ariaLabelledBy,
    forwardedRef
  });
  const content = resolveChildren(children);
  const {
    text,
    icon,
    counter
  } = useSlots(content, useMemo(() => ({
    _: {
      defaultWrapper: Text
    },
    text: {
      color: "inherit",
      size,
      className: "o-ui-checkbox-label"
    },
    icon: {
      size: embeddedIconSize(size),
      className: "o-ui-checkbox-icon"
    },
    counter: {
      variant: "divider",
      color: "inherit",
      size,
      reverse,
      pushed: true,
      className: "o-ui-checkbox-counter"
    }
  }), [size, reverse]));
  return /*#__PURE__*/_jsxs(Box, { ...mergeProps(rest, {
      as
    }, wrapperProps),
    children: [/*#__PURE__*/_jsx(VisuallyHidden, { ...inputProps
    }), /*#__PURE__*/_jsx("span", {
      className: "o-ui-checkbox-box"
    }), text, icon, counter]
  });
}
export const Checkbox = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerCheckbox, { ...props,
  forwardedRef: ref
}));
Checkbox.displayName = "Checkbox";