import { useImperativeHandle, useLayoutEffect, useRef } from "react";
import { cssModule, isNil, isNumber, normalizeSize, useAutoFocus, useControllableState, useEventCallback, useForwardInputApi } from "../../shared";
export function useCheckbox({
  cssModule: module,
  isInField,
  id,
  checked,
  defaultChecked,
  indeterminate,
  defaultIndeterminate,
  autoFocus,
  required,
  validationState,
  onChange,
  size,
  reverse,
  name,
  tabIndex,
  active,
  focus,
  hover,
  disabled,
  ariaLabel,
  ariaLabelledBy,
  forwardedRef
}) {
  const [isChecked, setIsChecked] = useControllableState(checked, defaultChecked, false);
  const [isIndeterminate, setIsIndeterminate] = useControllableState(indeterminate, defaultIndeterminate, false);
  const wrapperRef = useRef();
  const inputRef = useRef();
  useAutoFocus(inputRef, {
    isDisabled: !autoFocus,
    delay: isNumber(autoFocus) ? autoFocus : undefined
  });
  const forwardInputApi = useForwardInputApi(inputRef);
  useImperativeHandle(forwardedRef, () => {
    return forwardInputApi(wrapperRef);
  });
  const handleChange = useEventCallback(event => {
    const isInputChecked = event.target.checked;
    setIsChecked(isInputChecked);
    setIsIndeterminate(false);

    if (!isNil(onChange)) {
      onChange(event, isInputChecked);
    }
  });
  useLayoutEffect(() => {
    if (!isNil(inputRef.current)) {
      inputRef.current.indeterminate = !!isIndeterminate;
    }
  }, [inputRef, isIndeterminate]);
  return {
    isChecked,
    isIndeterminate,
    wrapperProps: {
      className: cssModule(module, isChecked && "checked", isIndeterminate && "indeterminate", isInField && "in-field", reverse && "reverse", validationState && validationState, disabled && "disabled", active && "active", focus && "focus", hover && "hover", normalizeSize(size)),
      ref: wrapperRef
    },
    inputProps: {
      id,
      as: "input",
      type: "checkbox",
      checked: isChecked,
      onChange: handleChange,
      disabled,
      name,
      tabIndex,
      "aria-label": ariaLabel,
      "aria-labelledby": ariaLabelledBy,
      "aria-checked": isIndeterminate ? "mixed" : isChecked,
      "aria-required": required ? true : undefined,
      "aria-invalid": validationState === "invalid" ? true : undefined,
      ref: inputRef
    }
  };
}