import { createContext, useContext } from "react";
import { isNil } from "../../shared";
import { jsx as _jsx } from "react/jsx-runtime";
export const FieldContext = /*#__PURE__*/createContext(null);
export function useFieldContext() {
  const context = useContext(FieldContext);

  if (!isNil(context)) {
    const {
      isGroup = false,
      ...rest
    } = context;
    const props = { ...rest,
      isGroup
    };
    return [props, true];
  }

  return [{}, false];
}
export function ClearFieldContext({
  children
}) {
  return /*#__PURE__*/_jsx(FieldContext.Provider, {
    value: null,
    children: children
  });
}
export function useFieldLabelProps({
  as: asProp
}) {
  const [{
    inputId,
    labelId,
    required,
    labelClassName,
    isGroup
  }, isInField] = useFieldContext();
  const as = isNil(asProp) ? isGroup ? "span" : "label" : asProp;
  const props = isInField && {
    id: labelId,
    required,
    htmlFor: as === "label" ? inputId : undefined,
    className: labelClassName,
    as
  };
  return [props || {}, isInField];
}
export function useFieldInputProps() {
  const [{
    id,
    inputId,
    labelId,
    messageId,
    validationState,
    required,
    fluid,
    disabled,
    inputClassName,
    isGroup
  }, isInField] = useFieldContext();
  const props = isInField && {
    validationState,
    id: !isGroup ? inputId : undefined,
    name: id,
    required,
    disabled,
    fluid,
    className: inputClassName,
    "aria-labelledby": !isGroup ? !isNil(labelId) ? labelId : undefined : undefined,
    "aria-describedby": !isGroup ? !isNil(messageId) ? messageId : undefined : undefined
  };
  return [props || {}, isInField];
}
export function useFieldMessageProps() {
  const [{
    messageId,
    fluid,
    validationState,
    messageClassName
  }, isInField] = useFieldContext();
  const props = isInField && {
    id: messageId,
    fluid,
    validationState,
    className: messageClassName,
    "aria-live": "polite"
  };
  return [props || {}, isInField];
}