import "./InputGroup.css";
import { Box } from "../../box";
import { Children, useMemo } from "react";
import { ClearFieldContext, useFieldInputProps } from "../../field";
import { ClearToolbar, useToolbarProps } from "../../toolbar";
import { InputGroupContext } from "./InputGroupContext";
import { TextAddon } from "./TextAddon";
import { cssModule, forwardRef, getSlotKey, isNil, mergeProps, omitProps, resolveChildren, useHasChild, useMergedRefs } from "../../shared";
import { jsx as _jsx } from "react/jsx-runtime";

function toAddon(element, key) {
  if (getSlotKey(element) === "text") {
    return /*#__PURE__*/_jsx(TextAddon, {
      children: element
    }, key);
  }

  return element;
}

export function InnerInputGroup({
  fluid,
  disabled,
  readOnly,
  as = "div",
  children,
  forwardedRef,
  ...rest
}) {
  const [toolbarProps] = useToolbarProps();
  const [fieldProps] = useFieldInputProps();
  const inputProps = mergeProps({
    fluid,
    disabled,
    readOnly
  }, omitProps(toolbarProps, ["orientation"]), fieldProps);
  const ref = useMergedRefs(forwardedRef);
  const transformedChildren = useMemo(() => {
    const elements = Children.toArray(resolveChildren(children)).filter(x => !isNil(x));

    if (elements.length <= 1) {
      throw new Error("An input group component must have 2 or 3 children.");
    }

    return Children.toArray(children).reduce((acc, x, index) => {
      acc.push(toAddon(x, index));
      return acc;
    }, []);
  }, [children]);
  const hasTextInput = useHasChild(".o-ui-input-group-text-input", ref);
  return /*#__PURE__*/_jsx(Box, { ...mergeProps(rest, {
      className: cssModule("o-ui-input-group", fluid && "fluid", hasTextInput && "has-text-input"),
      as,
      ref
    }),
    children: /*#__PURE__*/_jsx(ClearToolbar, {
      children: /*#__PURE__*/_jsx(ClearFieldContext, {
        children: /*#__PURE__*/_jsx(InputGroupContext.Provider, {
          value: inputProps,
          children: transformedChildren
        })
      })
    })
  });
}
export const InputGroup = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerInputGroup, { ...props,
  forwardedRef: ref
}));
InputGroup.displayName = "InputGroup";