import "./Radio.css";
import { ComponentProps, ElementType, FormEvent, ForwardedRef, ReactNode } from "react";
import { InteractionStatesProps } from "../../shared";
export interface InnerRadioProps extends InteractionStatesProps {
    /**
     * A controlled checked state value.
     */
    checked?: boolean | null;
    /**
     * The initial value of `checked` when uncontrolled.
     */
    defaultChecked?: boolean;
    /**
     * The value to associate with when in a group.
     */
    value: string;
    /**
     * Whether or not the radio should autoFocus on render.
     */
    autoFocus?: boolean | number;
    /**
     * Whether or not the radio should display as "valid" or "invalid".
     */
    validationState?: "valid" | "invalid";
    /**
     * Whether or not the radio is disabled.
     */
    disabled?: boolean;
    /**
     * Called when the radio checked state change.
     * @param {FormEvent} event - React's original synthetic event.
     * @param {boolean} isChecked - Whether or not the radio is checked.
     * @returns {void}
     */
    onValueChange?: (event: FormEvent<HTMLInputElement>, isChecked: boolean) => void;
    /**
     * @ignore
     */
    onChange?: (event: FormEvent<HTMLInputElement>, isChecked: boolean) => void;
    /**
     * Invert the order of the checkmark box and the label.
     */
    reverse?: boolean;
    /**
     * @ignore
     */
    tabIndex?: number;
    /**
     * Radio name.
     */
    name?: string;
    /**
     * An HTML element type or a custom React element type to render as.
     */
    as?: ElementType;
    /**
     * React children.
     */
    children: ReactNode;
    /**
     * @ignore
     */
    forwardedRef: ForwardedRef<any>;
}
export declare function InnerRadio(props: InnerRadioProps): JSX.Element;
export declare const Radio: import("../../shared").OrbitComponent<HTMLElement, InnerRadioProps>;
export declare type RadioProps = ComponentProps<typeof Radio>;
