import { DomScope } from "./useFocusScope";
export declare const VirtualFocusCssClass = "o-ui-focus";
export declare class ElementIterator<T> {
    private elements;
    private index;
    constructor(elements: T[], { from }?: {
        from?: number;
    });
    next(): T;
    previous(): T;
    reset({ from }?: {
        from?: number;
    }): void;
    get currentIndex(): number;
}
export interface FocusManagerOptions {
    isVirtual?: boolean;
    keyProp?: string;
    onFocus?: (activeElement: HTMLElement, options: Omit<FocusManagerOptions, "onFocus">) => void;
}
export interface FocusOptions {
    onFocus?: (activeElement: HTMLElement, options: Omit<FocusManagerOptions, "onFocus">) => void;
    onNotFound?: (options: Omit<FocusManagerOptions, "onFocus">) => void;
    canFocus?: (element: HTMLElement) => boolean;
}
export declare class FocusManager {
    private scope;
    private isVirtual;
    private keyProp;
    private onFocus;
    constructor(scope: DomScope, { isVirtual, keyProp, onFocus }?: FocusManagerOptions);
    private focusElement;
    focusFirst({ canFocus, ...options }?: FocusOptions): HTMLElement;
    focusLast({ canFocus, ...options }?: FocusOptions): HTMLElement;
    focusNext({ canFocus, ...options }?: FocusOptions): HTMLElement;
    focusPrevious({ canFocus, ...options }?: FocusOptions): HTMLElement;
    focusKey(key: string, options?: FocusOptions): HTMLElement;
    focusTarget(target: string, options?: FocusOptions): HTMLElement;
    search(query: string, options?: FocusOptions): HTMLElement;
    hasFocus(): boolean;
    getActiveElement(): HTMLElement;
    getActiveKey(): string;
}
export declare function useFocusManager(scope: DomScope, { isVirtual, keyProp, onFocus }?: FocusManagerOptions): FocusManager;
