import { isNil } from "./assertions";
import { useEventCallback } from "./useEventCallback";
import { useRefState } from "./useRefState";
export function useFocusWithin({
  onFocus,
  onBlur,
  isDisabled
} = {}) {
  const [isFocusWithinRef, setIsFocusWithin] = useRefState(false);
  const handleFocus = useEventCallback(event => {
    // We don't want to trigger multiple onFocus when moving focus inside the element. Only trigger if the currentTarget doesn't
    // include the relatedTarget (where the focus is moving).
    if (!event.currentTarget.contains(event.relatedTarget)) {
      if (!isNil(onFocus)) {
        onFocus(event);
      }

      setIsFocusWithin(true);
    }
  });
  const handleBlur = useEventCallback(event => {
    // We don't want to trigger onBlur and then immediately onFocus again when moving focus inside the element. Only trigger if the currentTarget doesn't
    // include the relatedTarget (where the focus is moving).
    if (isFocusWithinRef.current && !event.currentTarget.contains(event.relatedTarget)) {
      if (!isNil(onBlur)) {
        onBlur(event);
      }

      setIsFocusWithin(false);
    }
  });
  return isDisabled ? {} : {
    onFocus: handleFocus,
    onBlur: handleBlur
  };
}