import "./TextArea.css";
import { cssModule, forwardRef, isNil, mergeProps, useChainedEventCallback, useControllableState } from "../../shared";
import { Box } from "../../box";
import { useCallback, useLayoutEffect, useState } from "react";
import { useFieldInputProps } from "../../field";
import { useInput, useInputButton, wrappedInputPropsAdapter } from "../../input"; // Used to generate BoxProps instead of any in the auto-generated documentation
// eslint-disable-next-line @typescript-eslint/no-empty-interface

import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";

const pxToInt = value => {
  return !isNil(value) ? parseInt(value.replace("px", ""), 10) : 0;
};

export function InnerTextArea(props) {
  const [fieldProps] = useFieldInputProps();
  const {
    id,
    value,
    defaultValue,
    placeholder,
    resize,
    required,
    validationState,
    onValueChange,
    onChange,
    type = "text",
    autoFocus,
    button,
    disabled,
    readOnly,
    fluid,
    loading,
    rows: rowsProp,
    maxRows,
    active,
    focus,
    hover,
    "aria-label": ariaLabel,
    "aria-labelledby": ariaLabelledBy,
    wrapperProps: userWrapperProps,
    as = "div",
    forwardedRef,
    ...rest
  } = mergeProps(props, wrappedInputPropsAdapter(fieldProps));

  if (isNil(ariaLabel) && isNil(ariaLabelledBy) && isNil(placeholder)) {
    console.error("An input component must either have an \"aria-label\" attribute, an \"aria-labelledby\" attribute or a \"placeholder\" attribute.");
  }

  const [inputValue, setValue] = useControllableState(value, defaultValue, "");
  const [rows, setRows] = useState(rowsProp);
  const handleChange = useChainedEventCallback(onChange, event => {
    const newValue = event.target.value;
    setValue(newValue);

    if (!isNil(onValueChange)) {
      onValueChange(event, newValue);
    }
  });
  const {
    wrapperProps,
    inputProps,
    inputRef
  } = useInput({
    cssModule: "o-ui-text-area",
    id,
    value: inputValue,
    placeholder,
    required,
    validationState,
    onChange: handleChange,
    type,
    autoFocus,
    disabled,
    readOnly,
    fluid,
    loading,
    active,
    focus,
    hover,
    forwardedRef
  });
  const adjustRows = useCallback(() => {
    const input = inputRef.current;
    const {
      paddingBottom,
      paddingTop,
      lineHeight
    } = window.getComputedStyle(input);
    const padding = pxToInt(paddingTop) + pxToInt(paddingBottom);
    const currentRows = Math.floor((input.scrollHeight - padding) / pxToInt(lineHeight));
    const newRows = !isNil(maxRows) && currentRows > maxRows ? maxRows : currentRows;
    setRows(newRows);
  }, [inputRef, maxRows]);
  useLayoutEffect(() => {
    adjustRows();
  }, [adjustRows, inputValue]);
  const buttonMarkup = useInputButton(button, !disabled && !readOnly);

  const content = /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx("textarea", { ...mergeProps(rest, {
        "aria-label": ariaLabel,
        "aria-labelledby": ariaLabelledBy,
        rows,
        style: {
          ["--o-ui-resize"]: resize
        }
      }, inputProps)
    }), buttonMarkup]
  });

  return /*#__PURE__*/_jsx(Box, { ...mergeProps(userWrapperProps, {
      className: cssModule("o-ui-input", buttonMarkup && "has-button"),
      as
    }, wrapperProps),
    children: content
  });
}
export const TextArea = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerTextArea, { ...props,
  forwardedRef: ref
}));
TextArea.displayName = "TextArea";