import { EyeIcon, PrivacyIcon } from "../../icons";
import { IconButton } from "../../button";
import { TextInput } from "./TextInput";
import { forwardRef, mergeProps, useControllableState, useEventCallback } from "../../shared";
import { useInputGroupTextInputProps } from "../../input-group";
import { useState } from "react";
import { wrappedInputPropsAdapter } from "../../input"; // Used to generate BoxProps instead of any in the auto-generated documentation
// eslint-disable-next-line @typescript-eslint/no-empty-interface

import { jsx as _jsx } from "react/jsx-runtime";
export function InnerPasswordInput(props) {
  const [inputGroupProps] = useInputGroupTextInputProps();
  const {
    value,
    defaultValue,
    wrapperProps,
    forwardedRef,
    ...rest
  } = mergeProps(props, wrappedInputPropsAdapter(inputGroupProps));
  const [inputValue, setValue] = useControllableState(value, defaultValue, "");
  const [isHidden, setIsHidden] = useState(true);
  const handleChange = useEventCallback(event => {
    setValue(event.target.value);
  });
  const handleShowValue = useEventCallback(() => {
    setIsHidden(x => !x);
  }); // Always show the button to play nice with password managers.

  const showButtonMarkup = /*#__PURE__*/_jsx(IconButton, {
    variant: "ghost",
    onClick: handleShowValue,
    className: "o-ui-password-input-show-button",
    title: "Toggle password visibility",
    "aria-label": "Toggle password visibility",
    children: isHidden ? /*#__PURE__*/_jsx(EyeIcon, {}) : /*#__PURE__*/_jsx(PrivacyIcon, {})
  });

  return /*#__PURE__*/_jsx(TextInput, { ...mergeProps(rest, {
      value: inputValue,
      onChange: handleChange,
      wrapperProps: mergeProps(wrapperProps !== null && wrapperProps !== void 0 ? wrapperProps : {}, {
        className: "o-ui-password-input"
      }),
      type: isHidden ? "password" : "text",
      button: showButtonMarkup,
      ref: forwardedRef
    })
  });
}
export const PasswordInput = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerPasswordInput, { ...props,
  forwardedRef: ref
}));
PasswordInput.displayName = "PasswordInput";