import "./TextInput.css";
import { cssModule, forwardRef, isNil, mergeProps, omitProps, useChainedEventCallback, useControllableState } from "../../shared";
import { Box } from "../../box";
import { ClearInputGroupContext, useInputGroupTextInputProps } from "../../input-group";
import { useFieldInputProps } from "../../field";
import { useInput, useInputButton, useInputIcon, wrappedInputPropsAdapter } from "../../input";
import { useToolbarProps } from "../../toolbar"; // Used to generate BoxProps instead of any in the auto-generated documentation
// eslint-disable-next-line @typescript-eslint/no-empty-interface

import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export function InnerTextInput(props) {
  const [toolbarProps] = useToolbarProps();
  const [fieldProps] = useFieldInputProps();
  const [inputGroupProps] = useInputGroupTextInputProps();
  const contextualProps = mergeProps({}, omitProps(toolbarProps, ["orientation"]), fieldProps, inputGroupProps);
  const {
    id,
    value,
    defaultValue,
    placeholder,
    required,
    validationState,
    onValueChange,
    onChange,
    type = "text",
    autoFocus,
    icon,
    button,
    disabled,
    readOnly,
    fluid,
    loading,
    active,
    focus,
    hover,
    "aria-label": ariaLabel,
    "aria-labelledby": ariaLabelledBy,
    wrapperProps: userWrapperProps,
    as: As = "input",
    forwardedRef,
    ...rest
  } = mergeProps(props, wrappedInputPropsAdapter(contextualProps));

  if (isNil(ariaLabel) && isNil(ariaLabelledBy) && isNil(placeholder)) {
    console.error("An input component must either have an \"aria-label\" attribute, an \"aria-labelledby\" attribute or a \"placeholder\" attribute.");
  }

  const [inputValue, setValue] = useControllableState(value, defaultValue, "");
  const handleChange = useChainedEventCallback(onChange, event => {
    const newValue = event.target.value;
    setValue(newValue);

    if (!isNil(onValueChange)) {
      onValueChange(event, newValue);
    }
  });
  const {
    wrapperProps,
    inputProps
  } = useInput({
    cssModule: "o-ui-text-input",
    id,
    value: inputValue,
    placeholder,
    required,
    validationState,
    onChange: handleChange,
    type,
    autoFocus,
    disabled,
    readOnly,
    fluid,
    loading,
    active,
    focus,
    hover,
    forwardedRef
  });
  const iconMarkup = useInputIcon(icon, {
    disabled
  });
  const buttonMarkup = useInputButton(button, !disabled && !readOnly);

  const content = /*#__PURE__*/_jsxs(_Fragment, {
    children: [iconMarkup, /*#__PURE__*/_jsx(As, { ...mergeProps(rest, {
        "aria-label": ariaLabel,
        "aria-labelledby": ariaLabelledBy
      }, inputProps)
    }), /*#__PURE__*/_jsx(ClearInputGroupContext, {
      children: buttonMarkup
    })]
  });

  return /*#__PURE__*/_jsx(Box, { ...mergeProps(userWrapperProps, {
      className: cssModule("o-ui-input", iconMarkup && "has-icon", disabled && "disabled", buttonMarkup && "has-button")
    }, wrapperProps),
    children: content
  });
}
export const TextInput = forwardRef((props, ref) => /*#__PURE__*/_jsx(InnerTextInput, { ...props,
  forwardedRef: ref
}));
TextInput.displayName = "TextInput";